import gym
import wandb

from stable_baselines3 import A2C
from stable_baselines3.common.monitor import Monitor
from stable_baselines3.common.vec_env import DummyVecEnv
from wandb.integration.sb3 import WandbCallback


# Environment configuration :
config = {
    "policy_type": "MlpPolicy",
    "total_timesteps": 25000,
    "env_name": "CartPole-v1"}

# WandB config :
run = wandb.init(
    project="cartpole-sb3_a2c",
    config=config,
    sync_tensorboard=True,
    monitor_gym=True,
    save_code=True,
)


# Environment definition :
def make_env():
    environment = gym.make(config["env_name"])
    environment = Monitor(environment)  # record stats such as returns
    return environment


env = DummyVecEnv([make_env])

# Model definition :
model = A2C(config["policy_type"], env, verbose=1, tensorboard_log=f"./runs/{run.id}")

# Model training :

model.learn(
    total_timesteps=config["total_timesteps"],
    callback=WandbCallback(
        gradient_save_freq=100,
        model_save_path=f"./models/{run.id}",
        verbose=2,
    )
)
run.finish()
