import gym
import panda_gym
import wandb

from stable_baselines3 import A2C
from stable_baselines3.common.monitor import Monitor
from stable_baselines3.common.vec_env import DummyVecEnv
from wandb.integration.sb3 import WandbCallback


# Environment configuration :
config = {
    "policy_type": "MultiInputPolicy",
    "total_timesteps": 500000,
    "env_name": "PandaReachJointsDense-v2"}

# WandB config :
run = wandb.init(

    project="panda_reach-sb3_a2c",
    config=config,
    sync_tensorboard=True,
    monitor_gym=True,
    save_code=True,
)


# Environment definition :
def make_env():
    environment = gym.make(config["env_name"])
    environment = Monitor(environment)  # record stats such as returns
    return environment

env = DummyVecEnv([make_env])

# Model definition :
model = A2C(config["policy_type"], env, verbose=1, tensorboard_log=f"./runsPanda/{run.id}")

# Model training :
model.learn(
    total_timesteps=config["total_timesteps"],
    callback=WandbCallback(
        gradient_save_freq=1000,
        model_save_path=f"./modelsPanda/{run.id}",
        verbose=2,
    )
)
run.finish
